@@ -6,10 +6,10 @@ import os
 import json
 import logging
 import urllib3
-import ca_certs_locater
 
 from urllib3 import Retry
 
+from upwork import ca_certs_locater
 from upwork.oauth import OAuth
 from upwork.http import raise_http_error
 from upwork.utils import decimal_default
@@ -157,9 +157,8 @@ class Client(object):
             self.task_v2 = Task_V2(self)
 
         if team:
-            from upwork.routers.team import Team, Team_V2
-            self.team = Team(self)
-            self.team_v2 = Team_V2(self)
+            from upwork.routers.team import Team_V3
+            self.team_v3 = Team_V3(self)
 
         if timereport:
             from upwork.routers.timereport import TimeReport
